# Little python logger (lpl)
### Usage:
```
import lpl
LOGGER = logger.getLogger('module_name')
```
#### Example:
```
import lpl
LOGGER = logger.getLogger('module_name')
LOGGER.debug('debug')
LOGGER.info('info')
LOGGER.error('error')
LOGGER.critical('critical')
```
